/*
 * protocol.h in Virtual Combat
 * Copyright (c) 1993 by David Jameson
 *
 * Permission to use, copy, modify and distribute this software
 * for any purpose and without fee is hereby granted, provided that the
 * above copyright notice and this permission appear in the supporting
 * documentation.
 */

/* Definitions for game protocol */

#ifndef _PROTOCOL_H_
#define _PROTOCOL_H_

/* Modes */
#define NOTINUSE 1   /* Indicates that a player id is not in use */
#define CLOSEDOWN 2  /* About to close the connection */
#define TEXTMODE 4   /* Textmode -- client acts as a text terminal,
			sending input to server and displaying the text
			received from the server */
#define GAMEMODE 8   /* Gamemode -- the server waits to receive a packet
			of data from each client and then transmits all
			the packets back to every client */
#define HACKMODE 16  /* Hackers' mode */
#define TUNED_IN 32  /* Tuned in to game information messages */

/* Packet types */
#define TEXTDATA 0x80	  /* Text being sent from client to server or
			     vice versa */
#define ENTERGAME 0x81	  /* Message from server instructing client to
			     enter into gamemode, followed by position
			     of player in starting the game */
#define TEXTNOLOGIN 0x82  /* "Login refused" message from server to client */
#define TEXTCLOSE 0x83	  /* Message saying that connection is closing,
			     either from client to server or vice versa */
#define TEXTLOGIN 0x84	  /* "Login accepted" message from server to
			     client */
#define TEXTECHOON 0x85   /* Turn on local echoing of characters */
#define TEXTECHOOFF 0x86  /* Turn off local echoing of characters */


#define GAMEDATA 0x40	  /* Game information send from client to server or
			     vice-versa */
#define LEAVEGAME 0x41	  /* Message from client telling server
			     "I'm leaving gamemode" */
#define GAMECLOSE 0x42	  /* Message from client to server or vice versa
			     saying that connection is closing */
#define GAMEPARSE 0x43	  /* Message from server to client instructing client
			     to parse the (null terminated) data */
#define GAMECOLLIDE 0x44  /* Sent from client to server when a collision
			     occurs (with certain objects) */
#define GAMESHOOT 0x45	  /* Sent from client to server to indicate
			     that an object has been shot at (only certain
			     objects, such as other players) */
#define ENERGYLOSS 0x46   /* Sent to client when shot by another player.
			     Followed by amount of energy loss (1 byte). */
#define ENERGYGAIN 0x47   /* Followed by 1 byte representing amount of
			     energy gain */
#define EXPLOSION 0x48	  /* Sent to server to indicate that a projectile
			     has exploded.
			     Followed by ID of player who has been hit. */
#define GAMEPORTAL 0x49   /* Sent from client to server when a portal is
			     entered, specifying filename of new world */
#define GAMEWHO 0x4a	  /* Sent from client to server to ask for a list
			     of other players in the game */



#define TEXTPACKET 0x80
#define GAMEPACKET 0x40


/* Messages sent inside "GAMEDATA" packets.  All messages have a fixed
   size and any number of messages can be sent inside a single packet.
   The first byte of each message is the message type and the second
   byte is the id of the client who originated the message.  Extra
   data may be present depending on the type of message being sent. */

#if 0  /* no longer necessary */
#define GD_HELLO 0  /* Sent by a client entering the game.  Message
		       contains initial x, y and z coords followed by
		       a plr structure. */
#define GD_HELLO_LEN (NAMELEN + 3)  /* Total length of the message */
#define GD_BYE 1  /* Client is leaving the game */
#define GD_BYE_LEN 2
#define GD_UPDATE 2  /* Update of position and orientation
			(short dx, dy, dz, dyrot), send in network byte
			order. */
#define GD_UPDATE_LEN (2 + sizeof(update))
#define GD_SHOOT 3  /* Player is shooting another player.  Message contains
		       id of player being shot at. */
#define GD_SHOOT_LEN 3
#endif

#endif

